namespace FitConnect.Models;

public class FitConnectEnvironment {

    public static readonly FitConnectEnvironment Testing = new(
        "https://auth-testing.fit-connect.fitko.dev/token",
        new[] { "https://submission-api-testing.fit-connect.fitko.dev" },
        "https://routing-api-testing.fit-connect.fitko.dev",
        "https://portal.auth-testing.fit-connect.fitko.dev"
    );

    public static readonly FitConnectEnvironment Staging = new(
        "https://auth-refz.fit-connect.fitko.dev/token",
        new[] { "https://submission-api-refz.fit-connect.fitko.dev" },
        "https://routing-api-refz.fit-connect.fitko.dev",
        "https://portal.auth-refz.fit-connect.fitko.dev"
    );

    public static readonly FitConnectEnvironment Production = new(
        "https://auth.fit-connect.fitko.net/token",
        new[] { "https://submission-api.fit-connect.fitko.net" },
        "https://routing-api.fit-connect.fitko.net",
        "https://portal.auth.fit-connect.fitko.net"
    );

    public FitConnectEnvironment() {
    }

    /// <summary>
    ///     Default constructor.
    /// </summary>
    /// <param name="tokenUrl">URL for receiving the OAuth token</param>
    /// <param name="submissionUrl">URL for the submission API</param>
    /// <param name="routingUrl">URL for the routing API</param>
    public FitConnectEnvironment(string tokenUrl, string[] submissionUrl, string routingUrl,
        string sspUrl) {
        SspUrl = sspUrl;
        TokenUrl = tokenUrl;
        SubmissionUrl = submissionUrl;
        RoutingUrl = routingUrl;
    }

    /// <summary>
    /// Self service portal URL
    /// </summary>
    public string SspUrl { get; }
    /// <summary>
    ///     URL for receiving the OAuth token.
    /// </summary>
    public string TokenUrl { get; }

    /// <summary>
    ///     URL for the submission API.
    /// </summary>
    public string[] SubmissionUrl { get; }

    /// <summary>
    ///     URL for the routing API.
    /// </summary>
    public string RoutingUrl { get; }

    /// <summary>
    ///     Creates the endpoints for the given environment.
    /// </summary>
    /// <param name="fitConnectEnvironment">Environment to get endpoints for</param>
    /// <returns></returns>
    /// <exception cref="ArgumentException">Not all environments are ready to use</exception>
    // public static FitConnectEnvironment Create(FitConnectEnvironment fitConnectEnvironment) {
    //     return fitConnectEnvironment switch {
    //         FitConnectEnvironment.Development => DevEnvironment,
    //         FitConnectEnvironment.Testing => throw new ArgumentException(
    //             "Not approved for online testing"),
    //         FitConnectEnvironment.Production => throw new ArgumentException("NOT PRODUCTION READY"),
    //         _ => throw new ArgumentOutOfRangeException(nameof(fitConnectEnvironment),
    //             fitConnectEnvironment, null)
    //     };
    // }
}
